# 2022-07-14 - Fee Distributor v2

Deployment of a version of FeeDistributor, responsible for distributing tokens to veBAL holders. 
This version contains some bugfixes, and lets users (both EOAs and contracts) prevent others from initiating their claim process.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`FeeDistributor` artifact](./artifact/FeeDistributor.json)
